"""
Tests of the RecordingChannelGroup class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.unit import Unit

class TestUnit(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
